CachedMapTileReadFailure class

Indicates that the tile with the given URL was present in the cache, but could not be correctly read

This may be due to an unexpected corruption. It should not be thrown when the tile was written correctly.

Tile providers should catch this exception. Wherever possible, they should repair or replace the tile with a fresh & valid one.

The absence of this exception does not necessarily mean that the returned tile image bytes are valid, only that all the correctly written information was successfully read.

This exception is not usually for external consumption, except for tile provider implementations.

Implemented types

Constructors

CachedMapTileReadFailure({required String url, String? description, Object? originalError})
Create an exception which indicates the tile with the given URL was present in the cache, but could not be correctly read
const

Properties

description String?
An optional description of the read failure which caused this to be thrown
final
hashCode int
The hash code for this object.
no setterinherited
originalError Object?
If available, the original error/exception which caused this to be thrown (if not thrown manually)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
URL of the failed tile
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited