description property
An optional description of the read failure which caused this to be thrown
Usually, one of description or originalError should be provided.
Implementation
final String? description;
An optional description of the read failure which caused this to be thrown
Usually, one of description or originalError should be provided.
final String? description;