CameraConstraint.containLatitude constructor

const CameraConstraint.containLatitude([
  1. double a,
  2. double b
])

Constrains the edges of the camera to within latitudes a and b

Defaults to 90 & -90, to prevent the background color from appearing at the 'top' and 'bottom' of the typical map.

Implementation

const factory CameraConstraint.containLatitude([
  double a,
  double b,
]) = ContainCameraLatitude._;