ContainCamera class
Constrains the edges of the camera to within bounds
To instead constrain the center coordinate of the camera to these bounds, use ContainCameraCenter. If only latitude needs to be constrained, use ContainCameraLatitude.
See CameraConstraint for more information.
- Inheritance
-
- Object
- CameraConstraint
- ContainCamera
- Annotations
Properties
- bounds → LatLngBounds
-
The bounding box
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
constrain(
MapCamera camera) → MapCamera? -
Create a new constrained camera based off the current
cameraoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override