putTile method

  1. @override
Never putTile({
  1. required String url,
  2. required CachedMapTileMetadata metadata,
  3. Uint8List? bytes,
})
override

Add or update a tile in the cache

bytes is required if the tile is not already cached. The behaviour is implementation specific if bytes are not supplied when required.

Implementation

@override
Never putTile({
  required String url,
  required CachedMapTileMetadata metadata,
  Uint8List? bytes,
}) =>
    throw UnsupportedError('Must not be called if `isSupported` is `false`');