calculateBoundingBox method

List<LatLng> calculateBoundingBox(
  1. LatLng centerPoint,
  2. num distanceInKm
)

Calculate a bounding box around a center point with a specified distance in kilometers.

Given a center point centerPoint and a distance in kilometers distanceInKm, this function calculates and returns the bounding box around the center point.

Implementation

List<LatLng> calculateBoundingBox(LatLng centerPoint, num distanceInKm) {
  return BoundingBox.calculateBoundingBox(centerPoint, distanceInKm);
}