isGeoPointInBoundingBox method
Check if a given geographic point l is within a bounding box defined by the top-left and bottom-right corners.
Given a geographic point l and the top-left topLeft and bottom-right bottomRight corners of a bounding box, this function checks if the point is within the specified bounding box.
Implementation
bool isGeoPointInBoundingBox(LatLng l, LatLng topLeft, LatLng bottomRight) {
return BoundingBox.isGeoPointInBoundingBox(l, topLeft, bottomRight);
}