GeomMultiLine class

Constructors

GeomMultiLine({required List<List<LatLng>> lines})
GeomMultiLine.fromGeojson(Map<String, dynamic> inputJson, {bool withInvertedCoords = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
lines List<List<LatLng>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<List<List<double>>>
Retourne les coordonnées au format GeoJSON : [[lon, lat, ...], [lon, lat, ...], ...]
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited