InterractiveLayerHoverBuilder class

Will draw the hover map element widget

Constructors

InterractiveLayerHoverBuilder({required List<Widget> childWidgets, required PointerHoverEvent hoverEvent, required List<Polygon<Object>> polygons})

Properties

childWidgets List<Widget>
final
hashCode int
The hash code for this object.
no setterinherited
hoverEvent PointerHoverEvent
final
polygons List<Polygon<Object>>
final
position Offset
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() Widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited