InterractiveMapLayer class

Constructors

InterractiveMapLayer({List<MapLayerType> renderOrder = const [MapLayerType.polygons, MapLayerType.polylines, MapLayerType.markers, MapLayerType.imageOverlay, MapLayerType.circles], bool isInterractive = true, @Deprecated("too specialized logic, must be implemented out the package, this will be removed soon") DisplayPolygonLayerLogic? displayLogic, List<Polygon<Object>>? polygons, List<Polyline<Object>>? polylines, List<Marker>? markers, List<OverlayImage>? imageOverlays, List<CircleMarker<Object>>? circles, PolygonLayerParams? polygonLayerParams, void onTapDownLayer(InterractiveMapLayerTapDown interaction)?, void onHoverLayer(InterractiveMapLayerHover? interaction)?})
Constructor

Properties

circles List<CircleMarker<Object>>?
final
displayLogic → DisplayPolygonLayerLogic?
final
hashCode int
The hash code for this object.
no setterinherited
imageOverlays List<OverlayImage>?
final
isInterractive bool
if false, layer will bypass pointer event and let them pass through it
final
markers List<Marker>?
final
onHoverLayer → void Function(InterractiveMapLayerHover? interaction)?
final
onTapDownLayer → void Function(InterractiveMapLayerTapDown interaction)?
final
polygonLayerParams PolygonLayerParams?
Layer params
final
polygons List<Polygon<Object>>?
final
polylines List<Polyline<Object>>?
final
renderOrder List<MapLayerType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildOrderedLayerElements() List<Widget>
Rendu du groupe entier selon l'ordre choisi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited