InterractiveMapLayer constructor

InterractiveMapLayer({
  1. List<MapLayerType> renderOrder = const [MapLayerType.polygons, MapLayerType.polylines, MapLayerType.markers, MapLayerType.imageOverlay, MapLayerType.circles],
  2. bool isInterractive = true,
  3. @Deprecated("too specialized logic, must be implemented out the package, this will be removed soon") DisplayPolygonLayerLogic? displayLogic,
  4. List<Polygon<Object>>? polygons,
  5. List<Polyline<Object>>? polylines,
  6. List<Marker>? markers,
  7. List<OverlayImage>? imageOverlays,
  8. List<CircleMarker<Object>>? circles,
  9. PolygonLayerParams? polygonLayerParams,
  10. void onTapDownLayer(
    1. InterractiveMapLayerTapDown interaction
    )?,
  11. void onHoverLayer(
    1. InterractiveMapLayerHover? interaction
    )?,
})

Constructor

Implementation

InterractiveMapLayer({
  this.renderOrder = const [
    MapLayerType.polygons,
    MapLayerType.polylines,
    MapLayerType.markers,
    MapLayerType.imageOverlay,
    MapLayerType.circles, // Ajout des cercles dans l'ordre de rendu
  ],
  this.isInterractive = true,
  @Deprecated("too specialized logic, must be implemented out the package, this will be removed soon")
  this.displayLogic,
  this.polygons,
  this.polylines,
  this.markers,
  this.imageOverlays,
  this.circles, // Ajout des cercles
  this.polygonLayerParams,
  this.onTapDownLayer,
  this.onHoverLayer,
});