displayLogic property

  1. @Deprecated("too specialized logic, must be implemented out the package, this will be removed soon")
DisplayPolygonLayerLogic? displayLogic
final

Implementation

@Deprecated("too specialized logic, must be implemented out the package, this will be removed soon")
final DisplayPolygonLayerLogic? displayLogic;