MapActionMenuOverlaySettings class

Constructors

MapActionMenuOverlaySettings({MapMenuOverlayController? controller, Widget? menuOverlayWidget, bool canCloseMenuOverlayClickingOutside = true, Alignment overlayAlignement = Alignment.bottomRight, Offset? overlayOffset, double? overlayWidth, double? elevation, Color? backgroundColor, BorderRadius? borderRadius})

Properties

backgroundColor Color?
final
borderRadius BorderRadius?
final
canCloseMenuOverlayClickingOutside bool
final
controller MapMenuOverlayController?
will dispact actions from the parent widget to local (controlling from top to bottom)
final
elevation double?
final
hashCode int
The hash code for this object.
no setterinherited
final
overlayAlignement Alignment
final
overlayOffset Offset?
final
overlayWidth double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultOverlayWidth double
no setter

Static Methods

resolveReverseOverlayAnchors(Alignment align) → ({Alignment followerAnchor, Alignment targetAnchor})
we need to make that to reverse anchors