controller property
will dispact actions from the parent widget to local (controlling from top to bottom)
Implementation
final MapMenuOverlayController? controller;
will dispact actions from the parent widget to local (controlling from top to bottom)
final MapMenuOverlayController? controller;