isSupported property

bool get isSupported

Whether this caching provider is "currently supported": whether the tile provider should attempt to use it, or fallback to a non-caching alternative

Tile providers must not call getTile or putTile if this is false. getTile and putTile should gracefully throw if this is false. This should not throw.

If this is always false, consider mixing in or using DisabledMapCachingProvider directly.

Implementation

bool get isSupported;