MapControlBlock class
Constructors
-
MapControlBlock({required List<
MapControlType> types, required MapControlsStyling styling})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styling → MapControlsStyling
-
final
-
types
→ List<
MapControlType> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited