OwlnextMap class

Inheritance

Constructors

OwlnextMap({Key? key, TileLayer? overrideTile, required MapTileSwitchController tileController, List<MapControlBlock>? controlBlocks, required MapController mapController, bool? showControls = true, int? authorizedActions = InteractiveFlag.all, required MapLocation mapLocation, CameraConstraint? cameraConstraint, void handleClickMap(TapPosition, LatLng)?, void handleClickLayer(TapDownDetails details, Object tappedObject)?, void onMouseMoved(LatLng newCoordinates)?, void onPositionChanged(MapCamera mapCamera)?, double? maxZoom, double? minZoom, PolygonLayer<Object>? boundingBox, Widget? additionnalInteractionWidget, required List<InterractiveMapLayer> tracableLayers, InterractiveLayerHoverBuilder? hovered})
const

Properties

additionnalInteractionWidget Widget?
final
authorizedActions int?
final
boundingBox → PolygonLayer<Object>?
final
cameraConstraint → CameraConstraint?
final
controlBlocks List<MapControlBlock>?
Controlling
final
handleClickLayer → void Function(TapDownDetails details, Object tappedObject)?
final
handleClickMap → void Function(TapPosition, LatLng)?
final
hashCode int
The hash code for this object.
no setterinherited
hovered InterractiveLayerHoverBuilder?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mapController → MapController
final
mapLocation MapLocation
final
maxZoom double?
final
minZoom double?
final
onMouseMoved → void Function(LatLng newCoordinates)?
final
onPositionChanged → void Function(MapCamera mapCamera)?
final
overrideTile → TileLayer?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showControls bool?
final
tileController MapTileSwitchController
final
tracableLayers List<InterractiveMapLayer>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → OwlnextMapState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited