PointExtension<T extends num> extension
Extension methods for the math.Point class
- on
-
- Point<
T>
- Point<
Methods
-
ceil(
) → Point< int> -
Available on Point<
Create a new Point where the x and y values are rounded up to the nearest integer.T> , provided by the PointExtension extension -
floor(
) → Point< int> -
Available on Point<
Create a new Point where the x and y values are rounded down to the nearest integer.T> , provided by the PointExtension extension -
rotate(
num radians) → Point< double> -
Available on Point<
Create a new Point whose x and y values are rotated clockwise byT> , provided by the PointExtension extensionradians. -
round(
) → Point< int> -
Available on Point<
Create a new Point where the x and y values are rounded to the nearest integer.T> , provided by the PointExtension extension -
toDoublePoint(
) → Point< double> -
Available on Point<
Case the object to a Point object with double valuesT> , provided by the PointExtension extension -
toIntPoint(
) → Point< int> -
Available on Point<
Cast the object to a Point object with integer valuesT> , provided by the PointExtension extension -
toOffset(
) → Offset -
Available on Point<
Maps the Point to an Offset.T> , provided by the PointExtension extension -
unscaleBy(
Point< num> point) → Point<double> -
Available on Point<
Create new Point whose x and y values are divided by the respective values inT> , provided by the PointExtension extensionpoint.
Operators
-
operator /(
num factor) → Point< double> -
Available on Point<
Create a new Point where the x and y values are divided byT> , provided by the PointExtension extensionfactor.