PolylabelCalculator class

Places the Polygon.label at the point furthest away from the outline, calculated using a Dart implementation of Mapbox's 'polylabel' algorithm

This is more computationally expensive than other calculators but may yield better results.

The precision may be adjusted to change the computational expense and result accuracy. See documentation on precision for more information.

Implemented types

Properties

hashCode int
The hash code for this object.
no setteroverride
precision double
Threshold for when to stop dividing-and-conquering the polygon in the hopes of finding a better point with more distance to the polygon's outline
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Polygon<Object> polygon) LatLng
Given a polygon (and its points), calculate a single position at which the center of the label should be placed
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override