precision property
Threshold for when to stop dividing-and-conquering the polygon in the hopes of finding a better point with more distance to the polygon's outline
A higher number means less precision (less optimal placement), which is computationally cheaper (requires fewer iterations).
Specifying a number too small may result in program hangs.
Specified in geographical space, i.e. degrees. Therefore, as the polygon gets larger, this should also get larger.
Defaults to 0.0001.
Implementation
final double precision;