RotatedOverlayImage class

Spans an image across three corner points.

Therefore this layer can be used to rotate or skew an image on the map.

The image is transformed so that its corners touch the topLeftCorner, bottomLeftCorner and bottomRightCorner points while the top-right corner point is derived from the other points.

Inheritance
Annotations

Constructors

RotatedOverlayImage({Key? key, required ImageProvider<Object> imageProvider, required LatLng topLeftCorner, required LatLng bottomLeftCorner, required LatLng bottomRightCorner, FilterQuality? filterQuality = FilterQuality.medium, double opacity = 1, bool gaplessPlayback = false})
Create a new RotatedOverlayImage instance that can be provided to the OverlayImageLayer.
const

Properties

bottomLeftCorner LatLng
The coordinates of the bottom left corner of the image.
final
bottomRightCorner LatLng
The coordinates of the bottom right corner of the image.
final
filterQuality FilterQuality?
The FilterQuality of the image, used to define how high quality the overlay image should have on the map.
final
gaplessPlayback bool
Whether to continue showing the old image (true), or briefly show nothing (false), when the image provider changes. The default value is false.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
imageProvider ImageProvider<Object>
The ImageProvider for the image.
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacity double
The opacity in which the image should get rendered on the map.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeftCorner LatLng
The coordinates of the top left corner of the image.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited