SimpleMultiWorldCentroidCalculator class

Similar to SimpleCentroidCalculator, but supports correct placement of the Polygon.label when the polygon lies across the anti-meridian

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Polygon<Object> polygon) LatLng
Given a polygon (and its points), calculate a single position at which the center of the label should be placed
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited