BBoxUtils class

Constructors

BBoxUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

computeDistance({required LatLng pointA, required LatLng pointB}) double
getBoundsWithMargin(LatLngBounds visibleBounds, double marginInPixels, double zoomLevel) → LatLngBounds
latitudeDifferenceForZoom(double zoomLevel, double pixelThreshold, double latitude) double
metersPerPixel(double zoomLevel, double latitude) double
Calculate the meters per pixel at a given zoom level and latitude
metersToLatitude(double meters) double
Convert meters to latitude difference
metersToLongitude(double meters, double latitude) double
Convert meters to longitude difference based on the current latitude
redrawBoundingBox(LatLngBounds visibleBounds, double margin) → PolygonLayer<Object>