CachedMapTileReadFailure constructor
const
CachedMapTileReadFailure({})
Create an exception which indicates the tile with the given URL was present in the cache, but could not be correctly read
Usually, one of description or originalError should be provided.
Implementation
const CachedMapTileReadFailure({
required this.url,
this.description,
this.originalError,
});