putTile method
Never
putTile({
- required String url,
- required CachedMapTileMetadata metadata,
- Uint8List? bytes,
override
Add or update a tile in the cache
bytes is required if the tile is not already cached. The behaviour is
implementation specific if bytes are not supplied when required.
Implementation
@override
Never putTile({
required String url,
required CachedMapTileMetadata metadata,
Uint8List? bytes,
}) =>
throw UnsupportedError('Must not be called if `isSupported` is `false`');