GeoJsonDTO class
Représente un objet GeoJSON complet avec géométrie, CRS et BoundingBox.
Constructors
- GeoJsonDTO({BoundingBoxDTO? bbox, CrsDTO? crs, required GeomGeoJson geom})
- Constructeur principal.
- GeoJsonDTO.fromJson(dynamic input)
- Crée une instance à partir d'un JSON.
Properties
- bbox → BoundingBoxDTO?
-
Boîte englobante (BoundingBox) de la géométrie.
final
- crs → CrsDTO?
-
Système de référence de coordonnées (CRS).
final
- geom → GeomGeoJson
-
Géométrie principale (Point, LineString, Polygon, etc.).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Retourne le type de la géométrie (ex: 'Polygon', 'MultiPolygon').
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convertit cet objet en Map au format GeoJSON.
-
toJsonString(
) → String - Convertit cet objet en chaîne JSON.
-
toOuterPointsCoordsList(
) → List< LatLng> ? -
Retourne une liste de tous les points extérieurs des polygones.
Retourne
nullsi la géométrie n'est pas un polygone ou un multi-polygone. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited