GeomMultiPolygon class
Constructors
-
GeomMultiPolygon({required List<
GeomPolygon> multiPolygons}) -
GeomMultiPolygon.fromJson(Map<
String, dynamic> inputJson, {bool withInvertedCoords = false}) - Crée une instance à partir d'un GeoJSON.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
multiPolygons
↔ List<
GeomPolygon> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → List< List< List< >List< >double> > -
Convertit ce MultiPolygon en format GeoJSON.
Retourne : [[[
lon, lat, ...], ...], ...] -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited