InterractiveMapLayer class

Constructors

InterractiveMapLayer({DisplayPolygonLayerLogic? displayLogic, List<Polygon<Object>>? polygons, List<Polyline<Object>>? polylines, List<Marker>? markers, void onTapPolygon(InterractiveMapLayerTapDown interaction)?, void onHoverPolygons(InterractiveMapLayerHover? interaction)?, List<Polygon<Object>> polygonsFromHitValues(List<Object> hitValues)?})

Properties

currentlyHovered Set<Object>
getter/setter pair
displayLogic → DisplayPolygonLayerLogic?
final
hashCode int
The hash code for this object.
no setterinherited
markers List<Marker>?
final
onHoverPolygons → void Function(InterractiveMapLayerHover? interaction)?
final
onTapPolygon → void Function(InterractiveMapLayerTapDown interaction)?
final
polygons List<Polygon<Object>>?
final
polygonsFromHitValues List<Polygon<Object>> Function(List<Object> hitValues)?
final
polylines List<Polyline<Object>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onExit(PointerExitEvent event) → void
onTapDownPolygon(TapDownDetails details) → void
renderLayer({required List<Object>? layerObjects, required Widget layerBuilder(), required void onHover(PointerHoverEvent)?}) Widget?
renderLinesLayer() Widget?
renderMarkersLayer() Widget?
renderPolygonLayer() Widget?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited