displayLogic property
- @Deprecated("too specialized logic, must be implemented out the package, this will be removed soon")
final
Implementation
@Deprecated("too specialized logic, must be implemented out the package, this will be removed soon")
final DisplayPolygonLayerLogic? displayLogic;