MapCameraActor class

Constructors

MapCameraActor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fitCameraToGeojson({required GeoJsonDTO geojson, required MapController mapController, EdgeInsets? padding, LazyloadMapLayer? mapLazyloader, dynamic onEnd()?}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fitCameraToGeojsonList({required List<GeoJsonDTO> geojsons, required MapController mapController, EdgeInsets? padding, LazyloadMapLayer? mapLazyloader, dynamic onEnd()?}) Future<void>
fitCameraToPolygons({required List<Polygon<Object>>? polygons, required MapController mapController, EdgeInsets? padding, LazyloadMapLayer? mapLazyloader, Function? onEnd}) Future<void>
remap camera to Polygons bounding box with @param: padding for spacing in pixel