OwlnextMap class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- OwlnextMap
Constructors
-
OwlnextMap({Key? key, required List<
TileLayerProvider> tiles, required MapController mapController, bool? showControls = true, int? authorizedActions = InteractiveFlag.all, required MapLocation mapLocation, required List<Marker> markers, void handleClickMap(TapPosition, LatLng)?, void handleClickLayer(TapDownDetails details, Object tappedObject)?, void onMouseMoved(LatLng newCoordinates)?, void onPositionChanged(MapCamera mapCamera)?, double? maxZoom, double? minZoom, TileLayer? overrideTile, PolygonLayer<Object> ? boundingBox, Widget? additionnalInteractionWidget, required List<InterractiveMapLayer> tracableLayers, InterractiveLayerHoverBuilder? hovered, Future<void> onMapScreenshot(Uint8List? screenshotBytes)?, List<MapControlBlock> ? controlBlocks, void onScreenshotTriggerAvailable(Future<void> ())?}) -
const
Properties
- additionnalInteractionWidget → Widget?
-
final
-
final
-
boundingBox
→ PolygonLayer<
Object> ? -
final
-
controlBlocks
→ List<
MapControlBlock> ? -
final
- handleClickLayer → void Function(TapDownDetails details, Object tappedObject)?
-
final
- handleClickMap → void Function(TapPosition, LatLng)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hovered → InterractiveLayerHoverBuilder?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mapController → MapController
-
final
- mapLocation → MapLocation
-
final
-
markers
→ List<
Marker> -
final
- maxZoom → double?
-
final
- minZoom → double?
-
final
-
onMapScreenshot
→ Future<
void> Function(Uint8List? screenshotBytes)? -
final
- onMouseMoved → void Function(LatLng newCoordinates)?
-
final
- onPositionChanged → void Function(MapCamera mapCamera)?
-
final
-
onScreenshotTriggerAvailable
→ void Function(Future<
void> ())? -
final
- overrideTile → TileLayer?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showControls → bool?
-
final
-
tiles
→ List<
TileLayerProvider> -
final
-
tracableLayers
→ List<
InterractiveMapLayer> -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → OwlnextMapState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited