PolygonLabelPlacementCalculator.centroid constructor
- @literal
Places the Polygon.label at the centroid calculated using the signed area formula
This a little more computationally expensive than the simple centroid calculator, but yields better results, especially for non-convex polygons.
Implementation
@literal
const factory PolygonLabelPlacementCalculator.centroid() =
CentroidCalculator._;