drawInSingleWorld property
Whether polygons should only be drawn/projected onto a single world instead of potentially being drawn onto adjacent worlds (based on the shortest distance)
When set true with a CRS which does support
Crs.replicatesWorldLongitude, polygons will still be repeated across
worlds, but each polygon will only be drawn within one world.
Defaults to false.
Implementation
final bool drawInSingleWorld;