invertedFill property
Color to apply to the map where not covered by a polygon
Warning
On the web, inverted filling may not work as expected in some cases. It will not match the behaviour seen on native platforms. Avoid allowing polygons to intersect, and avoid using holes within polygons. This is because PolygonPainterFillMethod.evenOdd must be used on the web, which (due to Flutter issues), does not properly support this functionality.
Implementation
final Color? invertedFill;