painterFillMethod property
The method used by the painter to fill polygons and resolve overlaps & intersections
See documentation on each value in PolygonPainterFillMethod for more advantages and disadvantages of each method.
Defaults to PolygonPainterFillMethod.evenOdd on web & PolygonPainterFillMethod.pathCombine otherwise.
Implementation
final PolygonPainterFillMethod painterFillMethod;